using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Media;

namespace Infragistics.Samples.Models
{
    public class DataViewModel : ObservableModel
    {
        public DataViewModel()
        {
            AxisSettings stateOneAxisHidden = new AxisSettings { Visibility = Visibility.Collapsed};
            AxisSettings stateOneAxisVisible = new AxisSettings { Stroke = new SolidColorBrush(Colors.Green) };
            AxisSettings stateTwoAxis1 = new AxisSettings { Stroke = new SolidColorBrush(Colors.Red) };
            AxisSettings stateTwoAxis2 = new AxisSettings { Stroke = new SolidColorBrush(Colors.Blue) };

            DataState stateOne = new DataState();
            stateOne.DataSources.Add(new DataSample());
            stateOne.LeftAxisSettings = stateOneAxisVisible;
            stateOne.RightAxisSettings = stateOneAxisHidden;
            stateOne.ToggleDataState(true);

            DataState stateTwo = new DataState();
            stateTwo.DataSources.Add(new DataSample());
            stateTwo.DataSources.Add(new DataSample());
            stateTwo.LeftAxisSettings = stateTwoAxis1;
            stateTwo.RightAxisSettings = stateTwoAxis2;
            stateTwo.ToggleDataState(false);

            _dataStates = new ObservableCollection<DataState>();
            _dataStates.Add(stateOne);
            _dataStates.Add(stateTwo);

            _currentChartState = ChartStates.StateOne;
            
        }
       
        private ObservableCollection<DataState> _dataStates;
        public ObservableCollection<DataState> DataStates
        {
            get { return _dataStates; }
            set { if (_dataStates == value) return; _dataStates = value; 
                  OnPropertyChanged("DataStates"); }
        }

        private ChartStates _currentChartState;
        public ChartStates CurrentChartState
        {
            get { return _currentChartState; }
            set { if (_currentChartState == value) return; _currentChartState = value;
                  UpdateChartState();  OnPropertyChanged("CurrentChartState"); }
        }

        public void UpdateChartState()
        {
            if (this.CurrentChartState == ChartStates.StateOne)
            {
                this.DataStates[0].ToggleDataState(true);
                this.DataStates[1].ToggleDataState(false);
            }
            else
            {
                this.DataStates[0].ToggleDataState(false);
                this.DataStates[1].ToggleDataState(true);
            }
        }
        public void ToggleChartState()
        {
            this.CurrentChartState = this.CurrentChartState == ChartStates.StateOne ? ChartStates.StateTwo : ChartStates.StateOne;
        }
       

    }
    public enum ChartStates
    {
        StateOne,
        StateTwo
    }
    public class DataState : ObservableModel
    {
        public DataState()
        {
            IsEnabled = true;
            _dataSources = new ObservableCollection<DataCollection>();
            _leftAxisSettings = new AxisSettings();
            _rightAxisSettings = new AxisSettings();
        }

        protected bool IsEnabled { set; get; }

        public void ToggleDataState(bool enabled)
        {
            this.IsEnabled = enabled;

            this.SeriesVisibility = this.IsEnabled ? Visibility.Visible : Visibility.Collapsed;
            this.LeftAxisSettings.Visibility = this.IsEnabled ? Visibility.Visible : Visibility.Collapsed;
            this.RightAxisSettings.Visibility = this.IsEnabled ? Visibility.Visible : Visibility.Collapsed;
        }
        public void ToggleDataState()
        {
            ToggleDataState(!this.IsEnabled);
        }

       
     
        private ObservableCollection<DataCollection> _dataSources;
        public ObservableCollection<DataCollection> DataSources
        {
            get { return _dataSources; }
            set { if (_dataSources == value) return; _dataSources = value; 
                OnPropertyChanged("DataSources"); }
        }

        private AxisSettings _leftAxisSettings;
        /// <summary>
        /// Gets or sets the Settings of left axis
        /// </summary>
        public AxisSettings LeftAxisSettings
        {
            get { return _leftAxisSettings; }
            set { if (_leftAxisSettings == value) return; _leftAxisSettings = value;
                OnPropertyChanged("LeftAxisSettings"); }
        }
        private AxisSettings _rightAxisSettings;
        /// <summary>
        /// Gets or sets the Settings of right axis
        /// </summary>
        public AxisSettings RightAxisSettings
        {
            get { return _rightAxisSettings; }
            set { if (_rightAxisSettings == value) return; _rightAxisSettings = value;
            OnPropertyChanged("RightAxisSettings");
            }
        }

        private Visibility _visibility;
        /// <summary>
        /// Gets or sets the visibility of a series (DataSources)
        /// </summary>
        public Visibility SeriesVisibility
        {
            get { return _visibility; }
            set { if (_visibility == value) return; _visibility = value; OnPropertyChanged("SeriesVisibility"); }
        }

    }

    public class AxisSettings : ObservableModel
    {
        public AxisSettings()
        {
            this.StrokeThickness = 3.0;
            this.Stroke = new SolidColorBrush(Colors.Black);
            this.Visibility = Visibility.Visible;
            this.Min = double.NegativeInfinity;
            this.Max = double.PositiveInfinity;
        }

        private double _strokeThickness;
        public double StrokeThickness
        {
            get { return _strokeThickness; }
            set { if (_strokeThickness == value) return; _strokeThickness = value; OnPropertyChanged("StrokeThickness"); }
        }
        
        private double _min;
        public double Min
        {
            get { return _min; }
            set { if (_min == value) return; _min = value; OnPropertyChanged("Min"); }
        }

        private double _max;
        public double Max
        {
            get { return _max; }
            set { if (_max == value) return; _max = value; OnPropertyChanged("Max"); }
        }

        private Visibility _visibility;
        public Visibility Visibility
        {
            get { return _visibility; }
            set { if (_visibility == value) return; _visibility = value; OnPropertyChanged("Visibility"); }
        }


        private Brush _stroke;
        public Brush Stroke
        {
            get { return _stroke; }
            set { if (_stroke == value) return; _stroke = value; OnPropertyChanged("Stroke"); }
        }
    }

}